@@ -1,7 +1,7 @@
 package App::CheckArchiveFilename;
 
 our $DATE = '2016-09-09'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ our %SPEC;
 
 $SPEC{check_archive_filename} = {
     v => 1.1,
-    summary => 'Return information about archive types from filenames',
+    summary => 'Return information about archive & compressor types from filenames',
     args => {
         filenames => {
             schema => ['array*', of=>'filename*', min_len=>1],
@@ -24,6 +24,7 @@ $SPEC{check_archive_filename} = {
 };
 sub check_archive_filename {
     require Filename::Archive;
+    require Filename::Compressed;
 
     my %args = @_;
     my $filenames = $args{filenames};
@@ -31,20 +32,27 @@ sub check_archive_filename {
     my @res;
     for my $filename (@$filenames) {
         my $rec = {filename => $filename};
-        my $fres = Filename::Archive::check_archive_filename(
+        my $ares = Filename::Archive::check_archive_filename(
             filename => $filename);
-        if ($fres) {
+        if ($ares) {
             $rec->{is_archive} = 1;
-            $rec->{archive_name} = $fres->{archive_name};
-            if ($fres->{compressor_info}) {
+            $rec->{archive_name} = $ares->{archive_name};
+            if ($ares->{compressor_info}) {
                 $rec->{is_compressed} = 1;
                 # we'll just display the outermost compressor (e.g. compressor
                 # for file.tar.gz.bz2 is bzip2). this is rare though.
-                $rec->{compressor_name}   = $fres->{compressor_info}[0]{compressor_name};
-                $rec->{compressor_suffix} = $fres->{compressor_info}[0]{compressor_suffix};
+                $rec->{compressor_name}   = $ares->{compressor_info}[0]{compressor_name};
+                $rec->{compressor_suffix} = $ares->{compressor_info}[0]{compressor_suffix};
             }
         } else {
             $rec->{is_archive} = 0;
+            my $cres = Filename::Compressed::check_compressed_filename(
+                filename => $filename);
+            if ($cres) {
+                $rec->{is_compressed} = 1;
+                $rec->{compressor_name}   = $cres->{compressor_name};
+                $rec->{compressor_suffix} = $cres->{compressor_suffix};
+            }
         }
         push @res, $rec;
     }
@@ -55,7 +63,7 @@ sub check_archive_filename {
 }
 
 1;
-# ABSTRACT: Return information about archive types from filenames
+# ABSTRACT: Return information about archive & compressor types from filenames
 
 __END__
 
@@ -65,18 +73,18 @@ __END__
 
 =head1 NAME
 
-App::CheckArchiveFilename - Return information about archive types from filenames
+App::CheckArchiveFilename - Return information about archive & compressor types from filenames
 
 =head1 VERSION
 
-This document describes version 0.001 of App::CheckArchiveFilename (from Perl distribution App-CheckArchiveFilename), released on 2016-09-09.
+This document describes version 0.002 of App::CheckArchiveFilename (from Perl distribution App-CheckArchiveFilename), released on 2016-09-09.
 
 =head1 FUNCTIONS
 
 
 =head2 check_archive_filename(%args) -> [status, msg, result, meta]
 
-Return information about archive types from filenames.
+Return information about archive & compressor types from filenames.
 
 This function is not exported.
 
